import { Box } from "@chakra-ui/react";
import { usersRequestList } from "@/app/lib/users/action";
import { viewBatches } from "@/app/lib/batches/action";
import { getAssignPriorityRequestList } from "@/app/lib/assignment-priority/action";
import { prepareUsersDropdown } from "@/utils/common";
import { getIbcRequestList } from "@/app/lib/ibc/action";
import BatchForm from "@/app/admin/batches/components/form";
import { IbcInterface } from "@/types/settings/ibc/ibc";

const Edit = async ({ params }: { params: { id: number } }) => {
  const [users, batch, ibcs, assignmentPriority] = await Promise.all([
    usersRequestList({pagination:'false'}),
    viewBatches(params.id),
    getIbcRequestList(),
    getAssignPriorityRequestList(),
  ]);

  // Prepare data for users dropdown
  const usersDropdown = prepareUsersDropdown(users);

  // Prepare data for ibc dropdown
  const ibcsDropdown =
    ibcs?.data?.data && ibcs.data.data.length > 0
      ? ibcs.data.data.map((ibc: IbcInterface) => ({
          label: `${ibc.area_name}`,
          value: ibc.id,
        }))
      : [];

  // Prepare data for assignment priority dropdown
  const assignPriorityDropdown =
    assignmentPriority?.data?.data && assignmentPriority?.data?.data?.length > 0
      ? assignmentPriority.data.data.map((item: any) => ({
          label: item?.name,
          value: item?.id,
        }))
      : [];

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      <BatchForm
        usersDropdown={usersDropdown}
        ibcDropdown={ibcsDropdown}
        assignPriorityOption={assignPriorityDropdown}
        batch={batch}
        isEdit
      />
    </Box>
  );
};

export default Edit;
